@@ -10,7 +10,7 @@ use Exporter ();
 
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = '0.0107';
+$VERSION = '0.0108';
 
 =head1 NAME
 
@@ -59,7 +59,7 @@ See PERFORMANCE section below for sample usage.
 
 =head2 Creating an mcdb constant database
 
-A B<mcdb> file is created in three steps.  First call
+An B<mcdb> file is created in three steps.  First call
 C<new MCDB_File::Make($fname)>, where C<$fname> is the name of the
 database file to be created.  Secondly, call the C<insert> method
 once for each (I<key>, I<value>) pair.  Finally, call the C<finish>
@@ -72,8 +72,8 @@ pairs. This can be significantly faster because there is less crossing
 over the bridge from perl to C code. One simple way to do this is to pass
 in an entire hash, as in: C<< $mcdb_make->insert(%hash); >>.
 
-A simpler interface to B<cdb> file creation is provided by
-C<MCDB_File::Make::create $fname, %t>.  This creates a B<mcdb> file named
+A simpler interface to B<mcdb> file creation is provided by
+C<MCDB_File::Make::create $fname, %t>.  This creates an B<mcdb> file named
 C<$fname> containing the contents of C<%t>.
 
 =head1 EXAMPLES
@@ -131,12 +131,12 @@ Blank lines and lines beginning with B<#> are skipped.
     }
     print "\n";
 
-5. Although a B<mcdb> file is constant, you can simulate updating it
+5. Although an B<mcdb> file is constant, you can simulate updating it
 in Perl.  This is an expensive operation, as you have to create a
-new database, and copy into it everything that's unchanged from the
+new database, and copy into it everything that is unchanged from the
 old database.  (As compensation, the update does not affect database
-readers.  The old database is available for them, till the moment the
-new one is C<finish>ed.)
+readers.  The old database is available for them, up until the moment
+the new one is C<finish>ed.)
 
     use MCDB_File ();
 
@@ -168,7 +168,7 @@ new one is C<finish>ed.)
 Most users can ignore this section.
 
 An B<mcdb> file can contain repeated keys.  If the C<insert> method is
-called more than once with the same key during the creation of a B<mcdb>
+called more than once with the same key during the creation of an B<mcdb>
 file, that key will be repeated.
 
 Here's an example.
@@ -255,6 +255,25 @@ to filesystem, or you have run out of disk space.
 
 =head1 PERFORMANCE
 
+The MCDB_File C<madvise> method is a thin wrapper around the C library
+C<posix_madvise> and MCDB_File provides constants: C<MADV_NORMAL>
+C<MADV_RANDOM> C<MADV_SEQUENTIAL> C<MADV_WILLNEED> and C<MADV_DONTNEED>.
+
+For very large B<mcdb> files on which more than a few queries will be made,
+it is recommended that C<madvise> with C<MCDB_File::MADV_RANDOM> be called
+once on the object returned by C<tie>.
+
+  my $mcdb = tie %h, MCDB_File, "$file.mcdb" or die ...;
+  $mcdb->madvise(MCDB_File::MADV_RANDOM);
+  $value = $mcdb->find('key'); # slightly faster than $value = $h{key};
+  # ... (lots more queries)
+  undef $mcdb;
+  untie %h;
+
+For iterating over very large B<mcdb> files, it is recommended that
+C<madvise> with C<MCDB_File::MADV_SEQUENTIAL> be called once on the
+object returned by C<tie>.
+
 Sometimes you need to get the most performance possible out of a
 library. Rumour has it that perl's tie() interface is slow. In order
 to get around that you can use MCDB_File in an object oriented
@@ -286,6 +305,15 @@ gstrauss  <code () gluelogic.com>
 
 bootstrap MCDB_File $VERSION;
 
+# (not worth the mess of doing this in .xs; define the values here)
+use constant {
+  MADV_NORMAL     => 0, # MCDB_MADV_NORMAL
+  MADV_RANDOM     => 1, # MCDB_MADV_RANDOM
+  MADV_SEQUENTIAL => 2, # MCDB_MADV_SEQUENTIAL
+  MADV_WILLNEED   => 3, # MCDB_MADV_WILLNEED
+  MADV_DONTNEED   => 4  # MCDB_MADV_DONTNEED
+};
+
 sub CLEAR {
 	croak "Modification of an MCDB_File attempted"
 }
