@@ -62,7 +62,7 @@ extern int madvise(caddr_t, size_t, int);
 #endif
 
 /* code to hint to release memory pages every 32 MB (1u << 25) */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static unsigned char *
 mcdb_madv_initmark(unsigned char * const ptr,const uintptr_t sz,size_t offset);
@@ -90,7 +90,7 @@ mcdb_madv_initmark(unsigned char * const ptr,const uintptr_t sz,size_t offset)
     }                                                                          \
   } while (0)
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static bool
 writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz);
@@ -121,7 +121,7 @@ writev_loop(const int fd, struct iovec * restrict iov, int iovcnt, ssize_t sz)
 }
 
 /* read and dump data section of mcdb */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_dump(struct mcdb * const restrict m);
@@ -143,7 +143,7 @@ mcdbctl_dump(struct mcdb * const restrict m)
 
     mcdb_iter_init(&iter, m);
     posix_madvise(iter.map, (size_t)(iter.eod - (unsigned char *)iter.map),
-                  POSIX_MADV_SEQUENTIAL | POSIX_MADV_WILLNEED);
+                  POSIX_MADV_WILLNEED);
     while (mcdb_iter(&iter)) {
 
         klen = mcdb_iter_keylen(&iter);
@@ -219,7 +219,7 @@ mcdbctl_dump(struct mcdb * const restrict m)
 }
 
 /* Note: mcdbctl_stats() is equivalent test to pass/fail of djb cdbtest */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_stats(struct mcdb * const restrict m);
@@ -236,8 +236,7 @@ mcdbctl_stats(struct mcdb * const restrict m)
     unsigned long numd[11] = { 0,0,0,0,0,0,0,0,0,0,0 };
     int rv;
     bool rc;
-    posix_madvise(m->map->ptr, m->map->size,
-                  POSIX_MADV_SEQUENTIAL | POSIX_MADV_WILLNEED);
+    posix_madvise(m->map->ptr, m->map->size, POSIX_MADV_WILLNEED);
     if (!mcdb_validate_slots(m))
         return MCDB_ERROR_READFORMAT;
     mcdb_iter_init(&iter, m);
@@ -264,7 +263,7 @@ mcdbctl_stats(struct mcdb * const restrict m)
     return EXIT_SUCCESS;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_getseq(struct mcdb * const restrict m,
@@ -294,7 +293,7 @@ mcdbctl_getseq(struct mcdb * const restrict m,
     return EXIT_FAILURE;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_getall(struct mcdb * const restrict m,
@@ -321,7 +320,7 @@ mcdbctl_getall(struct mcdb * const restrict m,
     return EXIT_FAILURE;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_query(const int argc, char ** restrict argv);
@@ -399,7 +398,7 @@ mcdbctl_query(const int argc, char ** restrict argv)
     return rv;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv);
@@ -422,7 +421,7 @@ mcdbctl_make(const int argc __attribute_unused__, char ** const restrict argv)
     return rv;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_has_unique_keys(struct mcdb * const restrict m);
@@ -434,8 +433,7 @@ mcdbctl_has_unique_keys(struct mcdb * const restrict m)
     char *k;
     unsigned char *mark = mcdb_madv_initmark(m->map->ptr, m->map->size,
                                              MCDB_HEADER_SZ);
-    posix_madvise(m->map->ptr, m->map->size,
-                  POSIX_MADV_SEQUENTIAL | POSIX_MADV_WILLNEED);
+    posix_madvise(m->map->ptr, m->map->size, POSIX_MADV_WILLNEED);
     if (!mcdb_validate_slots(m))
         return MCDB_ERROR_READFORMAT;
     mcdb_iter_init(&iter, m);
@@ -455,7 +453,7 @@ mcdbctl_has_unique_keys(struct mcdb * const restrict m)
     return true;  /*keys are unique in mcdb*/
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first);
@@ -470,8 +468,7 @@ mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first)
                                              MCDB_HEADER_SZ);
     uint32_t dlen;
     int rv = EXIT_SUCCESS;
-    posix_madvise(m->map->ptr, m->map->size,
-                  POSIX_MADV_SEQUENTIAL | POSIX_MADV_WILLNEED);
+    posix_madvise(m->map->ptr, m->map->size, POSIX_MADV_WILLNEED);
     if (!mcdb_validate_slots(m))
         return MCDB_ERROR_READFORMAT;
     if (mcdb_makefn_start(&mk, m->map->fname, malloc, free) == 0
@@ -519,7 +516,7 @@ mcdbctl_make_unique_keys(struct mcdb * const restrict m, const bool first)
     return rv;
 }
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 static int
 mcdbctl_uniq(const int argc, char ** const restrict argv);
