@@ -122,26 +122,26 @@ INTERNAL nss_status_t
 nss_mcdb_endent(enum nss_dbtype);
 
 /* _nss_mcdb_get*ent() walks db returning successive keys with '=' tag char */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_getent(enum nss_dbtype,
                 const struct nss_mcdb_vinfo * restrict);
 
 /* similar to mcdb_findstart and mcdb_findnext; used for netdb netgroups */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_getentstart(enum nss_dbtype,
                      const struct nss_mcdb_vinfo * restrict);
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_getnetgrentnext(const struct nss_mcdb_vinfo * const restrict v);
 
 #if 0  /* implemented, but not enabling by default; often used only with NIS+ */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_getentnext(enum nss_dbtype,
@@ -149,13 +149,13 @@ nss_mcdb_getentnext(enum nss_dbtype,
 #endif
 
 /* _nss_mcdb_get*by*() generic queries */
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_get_generic(enum nss_dbtype,
                      const struct nss_mcdb_vinfo * restrict);
 
-__attribute_nonnull__
+__attribute_nonnull__()
 __attribute_warn_unused_result__
 INTERNAL nss_status_t
 nss_mcdb_buf_decode(struct mcdb * restrict,
