@@ -509,11 +509,12 @@ nss_mcdb_acct_make_group_encode(
 
 bool
 nss_mcdb_acct_make_passwd_parse(
-  struct nss_mcdb_make_winfo * const restrict w, char * restrict p)
+  struct nss_mcdb_make_winfo * const restrict w, char * restrict p, size_t plen)
 {
     char *b, *e;
     long n;
     struct passwd pw;
+    (void)plen; /*(unused)*/
 
     for (; *p; ++p) {
 
@@ -677,7 +678,7 @@ nss_mcdb_acct_make_passwd_parse(
 
 bool
 nss_mcdb_acct_make_group_parse(
-  struct nss_mcdb_make_winfo * const restrict w, char * restrict p)
+  struct nss_mcdb_make_winfo * const restrict w, char * restrict p, size_t plen)
 {
     char *b, *e;
     int c;
@@ -691,6 +692,7 @@ nss_mcdb_acct_make_group_parse(
         ? sc_ngroups_max
         : NSS_MCDB_NGROUPS_MAX;
     char *gr_mem[nmax+1];
+    (void)plen; /*(unused)*/
 
     gr.gr_mem = gr_mem;
 
@@ -736,7 +738,7 @@ nss_mcdb_acct_make_group_parse(
             if ((c = *(b = ++p)) == '\n')
                 break;                  /* done; no more aliases*/
             TOKEN_COMMADELIM_END(p);
-            if ((c = *p) == '\0')       /* error: invalid line */
+            if ((c = *p) == '\0')       /* error: invalid line; no newline */
                 return false;
             *p = '\0';
             if (n < nmax)
@@ -746,10 +748,6 @@ nss_mcdb_acct_make_group_parse(
         } while (c != '\n');
         gr.gr_mem[n] = NULL;
 
-        /* find newline (to prep for beginning of next line) */
-        if (c != '\n')   /* error: no newline; truncated? */
-            return false;
-
         /* process struct group */
         if (!w->encode(w, &gr))
             return false;
