@@ -35,7 +35,7 @@ PLASMA_ATTR_Pragma_once
 #include <shadow.h>
 
 /* buf size passed should be _SC_GETPW_R_SIZE_MAX + NSS_SP_HDRSZ (not checked)*/
-__attribute_nonnull__
+__attribute_nonnull__()
 size_t
 nss_mcdb_authn_make_spwd_datastr(char * restrict, const size_t,
 				 const struct spwd * const restrict);
@@ -43,14 +43,14 @@ nss_mcdb_authn_make_spwd_datastr(char * restrict, const size_t,
 #endif /* !defined(_AIX) && !defined(__CYGWIN__) */
 
 
-__attribute_nonnull__
+__attribute_nonnull__()
 bool
 nss_mcdb_authn_make_spwd_encode(
   struct nss_mcdb_make_winfo * const restrict,
   const void * const);
 
 
-__attribute_nonnull__
+__attribute_nonnull__()
 bool
 nss_mcdb_authn_make_shadow_parse(
   struct nss_mcdb_make_winfo * const restrict, char * restrict, size_t);
