@@ -6,20 +6,20 @@
  *
  * Copyright (c) 2012, Glue Logic LLC. All rights reserved. code()gluelogic.com
  *
- *  This file is part of mcdb.
+ *  This file is part of plasma.
  *
- *  mcdb is free software: you can redistribute it and/or modify it under
+ *  plasma is free software: you can redistribute it and/or modify it under
  *  the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 2.1 of the License, or
  *  (at your option) any later version.
  *
- *  mcdb is distributed in the hope that it will be useful,
+ *  plasma is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public License
- *  along with mcdb.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with plasma.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define PLASMA_ATOMIC_C99INLINE_FUNCS
@@ -336,6 +336,7 @@ plasma_atomic_compare_exchange_n_ptr (void ** const ptr,
                                       const enum memory_order success_memmodel,
                                       const enum memory_order failure_memmodel);
 
+#ifndef plasma_atomic_not_implemented_64
 __attribute_regparm__((3))
 extern inline
 bool
@@ -353,6 +354,7 @@ plasma_atomic_compare_exchange_n_64 (uint64_t * const ptr,
                                      const bool weak,
                                      const enum memory_order success_memmodel,
                                      const enum memory_order failure_memmodel);
+#endif
 
 __attribute_regparm__((3))
 extern inline
@@ -386,6 +388,7 @@ void *
 plasma_atomic_exchange_n_ptr (void ** const ptr, void * const newval,
                               const enum memory_order memmodel);
 
+#ifndef plasma_atomic_not_implemented_64
 __attribute_regparm__((3))
 extern inline
 uint64_t
@@ -395,6 +398,7 @@ __attribute_regparm__((3))
 uint64_t
 plasma_atomic_exchange_n_64 (uint64_t * const ptr, const uint64_t newval,
                              const enum memory_order memmodel);
+#endif
 
 __attribute_regparm__((3))
 extern inline
