@@ -213,19 +213,15 @@
 #ifndef __attribute_nonnull__
 #if __has_attribute(nonnull) \
  || __GNUC_PREREQ(3,3)
-#define __attribute_nonnull__  __attribute__((__nonnull__))
+#define __attribute_nonnull__(params)  __attribute__((__nonnull__ params))
 #else
-#define __attribute_nonnull__
+#define __attribute_nonnull__(params)
 #endif
 #endif
 
+/*(deprecated; compat with older plasma macro)*/
 #ifndef __attribute_nonnull_x__
-#if __has_attribute(nonnull) \
- || __GNUC_PREREQ(3,3)
-#define __attribute_nonnull_x__(x)  __attribute__((__nonnull__ x))
-#else
-#define __attribute_nonnull_x__(x)
-#endif
+#define __attribute_nonnull_x__(x)  __attribute_nonnull__(x)
 #endif
 
 #ifndef __attribute_returns_nonnull__
@@ -496,6 +492,15 @@
 #endif
 #endif
 
+#ifndef __attribute_fallthrough__
+#if __has_attribute(fallthrough) \
+ || __GNUC_PREREQ(7,0)
+#define __attribute_fallthrough__  __attribute__((__fallthrough__));
+#else
+#define __attribute_fallthrough__  /* fall through */
+#endif
+#endif
+
 #ifndef __attribute_regparm__
 #if __has_attribute(regparm) \
  || (defined(__GNUC__) && (defined(__i386__) || defined(__x86_64__)))
